@@ -2,6 +2,17 @@ from ._models_hyperelasticity import (
     NeoHooke,
 )
 
+try:
+    from ._models_hyperelasticity_ad import (
+        isochoric_volumetric_split,
+        neo_hooke,
+        yeoh,
+        third_order_deformation,
+        ogden,
+    )
+except:
+    pass
+
 from ._models_linear_elasticity import (
     LinearElastic,
     LinearElasticTensorNotation,
@@ -20,6 +31,13 @@ from ._user_materials import (
     LinearElasticPlasticIsotropicHardening,
 )
 
+try:
+    from ._user_materials_hyperelastic import (
+        UserMaterialHyperelastic,
+    )
+except:
+    pass
+
 from ._user_materials_models import (
     linear_elastic,
     linear_elastic_plastic_isotropic_hardening,
