@@ -20,8 +20,12 @@ from ._tensor import (
     ddot,
     tovoigt,
     sym,
+    reshape,
+    ravel,
 )
 
+from numpy import sqrt
+
 from ._field import (
     defgrad,
     strain,
