@@ -1,4 +1,7 @@
 from ._base import Scheme
 from ._triangle import Triangle
 from ._tetra import Tetrahedron
-from ._gausslegendre import GaussLegendre
+from ._gausslegendre import (
+    GaussLegendre,
+    GaussLegendreBoundary,
+)
